function mesh2txt(points, connectivityList, color, outputFileName)
%% mesh2txt export mesh to txt file for LaTeX postprocessing 
% Export mesh to txt file for LaTeX postprocessing
%
%  INPUTS
%   points: list of points, double [nPoints x 3]
%   connectivityList: list of triangle vertices, double [nTriangles x 1]
%   color: triangles fill color, double [3 x 1] or [nTriangles x 1]
%   outputFileName: name of outputFile, char [N x 1]
%
% Included in AToM, info@antennatoolbox.com
%  2018, Michal Masek, CTU in Prague, michal.masek@antennatoolbox.com

%% check inputs
nInputs = nargin;
% default file name
if nInputs < 4 || isempty(outputFileName)
    outputFileName = 'mesh.txt';
end
% default color
if nInputs < 3 || isempty(color)
    color = [1, 1, 0.6]; % colorbrewer Paired-12-K
end

%% color of triangles
nTriangles = size(connectivityList, 1);
if size(color, 1) < nTriangles
    color = repmat(color(1, :), nTriangles, 1);
end

%% prepare data to save
dataToSave = [(1:nTriangles)', ...
    points(connectivityList(:,1), :),...
    points(connectivityList(:,2), :),...
    points(connectivityList(:,3), :),...
    color];

%% save file
lineFormat = [ '%5d ', repmat('% 2.5f ', 1, 12) '\n'];
fileID = fopen(outputFileName, 'w');
fprintf(fileID, lineFormat, dataToSave.');
fclose(fileID);